﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Administration;

namespace Chapter2
{
  class Program
  {
    static void Main(string[] args)
    {
      Program p = new Program();
      p.ListRootWebFolders();
      Console.WriteLine("Press enter to exit...");
      Console.ReadLine();
    }

    void ListServicesOnServer()
    {
      Console.WriteLine("Services on local server");
      foreach (SPServiceInstance service in SPServer.Local.ServiceInstances)
      {
        Console.WriteLine(service.TypeName);
      }
    }

    void ListServersInFarm()
    {
      Console.WriteLine("Servers in farm:");
      foreach (SPServer server in SPFarm.Local.Servers)
      {
        Console.WriteLine(server.DisplayName);
      }
    }

    void ListWebApplications()
    {
      Console.WriteLine("Web applications in farm:");
      SPWebService webService = SPFarm.Local.Services.OfType<SPWebService>().First();
      foreach (SPWebApplication app in webService.WebApplications)
      {
        Console.WriteLine(app.Name);
      }
    }

    void ListSitesInSiteCollection()
    {
      Console.WriteLine("Sites in site collection:");
      using (SPSite site = new SPSite("http://win-hs8gzgtapbh:46853/default.aspx"))
      {
        foreach (SPWeb web in site.AllWebs)
        {
          Console.WriteLine(web.Title);
        }
      }
    }

    void ListListsInRootWeb()
    {
      Console.WriteLine("Lists in site collection root site:");
      using (SPSite site = new SPSite("http://win-hs8gzgtapbh:46853"))
      {
        using (SPWeb root = site.RootWeb)
        {
          foreach (SPList list in root.Lists)
          {
            Console.WriteLine(list.Title);
          }
        }
      }
    }

    void ListRootWebFiles()
    {
      Console.WriteLine("Files in site collection root site:");
      using (SPSite site = new SPSite("http://win-hs8gzgtapbh:46853"))
      {
        using (SPWeb root = site.RootWeb)
        {
          foreach (SPFile file in root.Files)
          {
            Console.WriteLine(file.Name);
          }
        }
      }
    }

    void ListRootWebFolders()
    {
      Console.WriteLine("Files in site collection root site:");
      using (SPSite site = new SPSite("http://win-hs8gzgtapbh:46853"))
      {
        using (SPWeb root = site.RootWeb)
        {
          listFolders(root.Folders);
        }
      }
    }

    void listFolders(SPFolderCollection folders)
    {
      foreach (SPFolder folder in folders)
      {
        Console.Write(folder.Name + "\t");
        if (folder.DocumentLibrary != null)
        {
          Console.WriteLine("Corresponding library: " + folder.DocumentLibrary.Title);
        }
        else
        {
          Console.WriteLine(string.Empty);
        }
        listFolders(folder.SubFolders);
      }
    }


    void ListRootWebMasterPages()
    {
      Console.WriteLine("Master Page files in site collection root site:");
      using (SPSite site = new SPSite("http://win-hs8gzgtapbh:46853"))
      {
        using (SPWeb root = site.RootWeb)
        {
          SPList masterPages = root.Lists.TryGetList("Master Page Gallery");
          if (masterPages != null)
          {
            SPListItemCollection items = masterPages.Items;
            foreach (SPListItem fileItem in items)
            {
              SPFile file = fileItem.File;
              Console.WriteLine(file.Name + "\t" + string.Format("{0:###,### bytes}", file.Length));
            }
          }
        }
      }
    }


    void UpdateDescription()
    {
      Console.WriteLine("Lists in site collection root site:");
      using (SPSite site = new SPSite("http://win-hs8gzgtapbh:46853"))
      {
        using (SPWeb root = site.RootWeb)
        {
          root.Description = "My New Description";
          root.Update();
        }
      }
    }

    private void UseSPContext(string myList)
    {
      SPList list = SPContext.Current.Web.Lists.TryGetList(myList);
      if (list == null)
      {
        //Do Something
      }
    }

    public override void ItemUpdating(SPItemEventProperties properties)
    {
      string title = properties.Web.Title;
    }

  }
}
