﻿using System;
using Microsoft.SharePoint;
using Microsoft.SharePoint.WebControls;
using System.Web.UI.WebControls;
using Microsoft.SharePoint.Administration;

namespace TranslatorServiceApplicationDemo.Layouts.TranslatorServiceApplicationDemo
{
  public partial class TranslationServiceCreate : LayoutsPageBase
  {

    protected IisWebServiceApplicationPoolSection m_applicationPoolSection;
    protected TextBox m_asAppName;
    protected RequiredFieldValidator m_asAppNameValidator;
    protected CheckBox m_default;
    protected CustomValidator m_uniqueNameValidator;

    protected void CancelButtonClick(object sender, EventArgs e)
    {
      this.SendResponseForPopUI();
    }

    protected void OkButton_Click(object sender, EventArgs e)
    {
      if (this.Page.IsValid)
      {
        if (this.ApplicationId == Guid.Empty)
        {
          this.CreateNewServiceApp();
        }
        this.SendResponseForPopUI();
      }
    }

    protected override void OnInit(EventArgs e)
    {
      base.OnInit(e);
      ((DialogMaster)this.Page.Master).OkButton.Click += new EventHandler(this.OkButton_Click);
    }

    protected override void OnLoad(EventArgs e)
    {
      base.OnLoad(e);
      if (!this.Page.IsPostBack)
      {
        Guid applicationId = this.ApplicationId;
        if (applicationId != Guid.Empty)
        {
          if (SPFarm.Local == null)
          {
            throw new NullReferenceException("SPFarm.Local");
          }

          TranslationServiceApplication application =
              SPFarm.Local.GetObject(applicationId) as TranslationServiceApplication;

          if (application != null)
          {
            this.m_asAppName.Text = application.Name;
          }
          else
          {
            throw new Exception();
          }
        }
      }
    }

    private void CreateNewServiceApp()
    {
      using (SPLongOperation operation = new SPLongOperation(this))
      {
        operation.Begin();
        try
        {
          string name = this.m_asAppName.Text.Trim();
          if (SPFarm.Local == null)
            throw new NullReferenceException("SPFarm.Local");

          TranslationServiceApplication serviceApplication = CreateServiceApplication(name);

          CreateServiceApplicationProxy(name, serviceApplication);

          if (this.m_default.Checked)
          {
            serviceApplication.RegisterAsDefaultApplication();
          }
        }
        catch (Exception ex)
        {
          throw new SPException("Failed to create service applicaton", ex);
        }
      }
    }

    private static void CreateServiceApplicationProxy(string name, TranslationServiceApplication serviceApplication)
    {
      // Create the service application proxy
      SPServiceApplicationProxy proxy = TranslationService.Local.CreateProxy(name, serviceApplication, null);
      proxy.Update(true);
      proxy.Provision();
    }

    private TranslationServiceApplication CreateServiceApplication(string name)
    {
      //Get the application pool to be used
      SPIisWebServiceApplicationPool appPool = null;

      if (this.m_applicationPoolSection != null)
      {
        appPool = this.m_applicationPoolSection.GetOrCreateApplicationPool();
      }

      // Create the service applicaton
      TranslationServiceApplication serviceApplication = TranslationService.Local.CreateApplication(name, appPool) as TranslationServiceApplication;

      // It seems redundant, but update needs to be called 
      // before AND after the endpoint gets provisioned.
      serviceApplication.Update();
      serviceApplication.AddServiceEndpoint(string.Empty, SPIisWebServiceBindingType.Http);

      serviceApplication.Update(true);
      serviceApplication.Provision();

      return serviceApplication;
    }
        
    protected void ValidateUniqueName(object sender, ServerValidateEventArgs e)
    {
      string name = this.m_asAppName.Text.Trim();
      TranslationServiceApplication applicationByName = TranslationServiceApplication.GetLocalApplicationByName(name);
      bool flag = true;
      if (applicationByName != null)
      {
        flag = false;
      }
      e.IsValid = flag;
      this.m_uniqueNameValidator.ErrorMessage = "The specified service application name is already in use.";
    }

    // Properties
    private Guid ApplicationId
    {
      get
      {
        Guid empty = Guid.Empty;
        if (base.Request.QueryString != null)
        {
          string str = base.Request.QueryString["appid"];
          if (string.IsNullOrEmpty(str))
          {
            return empty;
          }
          try
          {
            empty = new Guid(str);
          }
          catch (FormatException)
          {
            throw new Exception();
          }
        }
        return empty;
      }


    }
  }
}

