using System;
using System.Runtime.InteropServices;
using System.Security.Permissions;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Security;
using Microsoft.SharePoint.Administration;
using System.Diagnostics;

namespace TranslatorServiceApplicationDemo.Features.Feature1
{
  /// <summary>
  /// This class handles events raised during feature activation, deactivation, installation, uninstallation, and upgrade.
  /// </summary>
  /// <remarks>
  /// The GUID attached to this class may be used during packaging and should not be modified.
  /// </remarks>

  [Guid("ca57b923-4ef7-43d5-8de7-06c1ce30fe01")]
  public class Feature1EventReceiver : SPFeatureReceiver
  {

    public override void FeatureActivated(SPFeatureReceiverProperties properties)
    {

      TranslationService svc = TranslationService.Local;

      Trace.WriteIf(svc != null, "Picked up existing TranslationService");

      if (svc == null)
      {
        svc = new TranslationService(SPFarm.Local);
        svc.Update();
        Trace.WriteLine("Created TranslationService");
      }     
    }

    public override void FeatureDeactivating(SPFeatureReceiverProperties properties)
    {
      TranslationService svc = TranslationService.Local;

      if (svc != null)
      {
        svc.Unprovision();

        foreach (var instance in svc.Instances)
        {
          instance.Unprovision();
          instance.Delete();
        }

        foreach (var application in svc.Applications)
        {
          application.Unprovision();
          application.Delete();
        }

        svc.Delete();
        Trace.WriteLine("Deleted TranslationService");
      }
    }
  }
}
