﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint.Administration;
using Microsoft.SharePoint.Utilities;
using System.IO;

namespace TranslatorServiceApplicationDemo
{
  [System.Runtime.InteropServices.Guid("0B42E5CF-B5BC-438C-997F-996E61CE572B")]
  class TranslationServiceApplication : SPIisWebServiceApplication
  {

    public TranslationServiceApplication()
    {
    }
    
    internal TranslationServiceApplication(string name, TranslationService service, SPIisWebServiceApplicationPool applicationPool)
      : base(name, service, applicationPool)
    {
    }

    public override SPAdministrationLink ManageLink
    {
      get
      {
        string linkWithQuerystring =
            string.Concat("/_admin/TranslationDemo/TranslationServiceManage.aspx?appid=",
            this.Id.ToString());
        return new SPAdministrationLink(linkWithQuerystring);
      }
    }

    protected override string InstallPath
    {
      get
      {
        return Path.GetFullPath(SPUtility.GetGenericSetupPath(@"WebServices\TranslationDemo"));
      }
    }

    protected override string VirtualPath
    {
      get
      {
        return "TranslationService.svc";
      }
    }

    public override void Provision()
    {
      base.Provision();

      TranslationServiceInstance inst = SPServer.Local.ServiceInstances.OfType<TranslationServiceInstance>().FirstOrDefault();

      if (inst == null)
      {
        inst = new TranslationServiceInstance(SPServer.Local, this.Service as TranslationService);
        inst.Name = "TranslationServiceInstance";
        inst.Update();
        inst.Provision();
      }
      
      this.Update();
    }

    public override void Unprovision(bool deleteData)
    {
      base.Status = SPObjectStatus.Unprovisioning;
      this.Update();

      if (this.Service.Applications.Count == 1)
      {
        SPServiceInstance inst = this.ServiceInstances.FirstOrDefault();
        if (inst != null)
        {
          inst.Unprovision();
          inst.Delete();
        }
      }

      base.Unprovision(deleteData);
      base.Status = SPObjectStatus.Disabled;
      this.Update();
    }

    internal static TranslationServiceApplication GetLocalApplicationByName(string name)
    {
      return TranslationService.Local.GetWebApplicationByName(name);
    }

    internal void RegisterAsDefaultApplication()
    {
      TranslationServiceApplicationProxy proxyForApplicationName = GetProxyForApplicationName(base.Name);
      if (proxyForApplicationName != null)
      {
        SPServiceApplicationProxyGroup group = SPServiceApplicationProxyGroup.Default;
        group.Add(proxyForApplicationName);
        group.Update(true);
      }
      else
      {
        throw new ApplicationException("Failed to register as default service application.");
      }
    }

    internal static TranslationServiceApplicationProxy GetProxyForApplicationName(string applicationName)
    {
      string proxyNameForApplicationName = GetProxyNameForApplicationName(applicationName);

      if (!string.IsNullOrEmpty(proxyNameForApplicationName))
      {
        TranslationServiceProxy proxy = SPFarm.Local.ServiceProxies.GetValue<TranslationServiceProxy>();
        if (proxy != null)
        {
          TranslationServiceApplicationProxy proxy2 = proxy.ApplicationProxies.GetValue<TranslationServiceApplicationProxy>(proxyNameForApplicationName);
          if (proxy2 != null)
          {
            return proxy2;
          }
        }
      }

      return null;
    }

    internal static string GetProxyNameForApplicationName(string applicationName)
    {
      foreach (TranslationServiceApplicationProxy proxy2 in SPFarm.Local.ServiceProxies.GetValue<TranslationServiceProxy>().ApplicationProxies)
      {
        if (proxy2.TranslationApplication.Name == applicationName)
        {
          return proxy2.Name;
        }
      }

      return string.Empty;
    }

    public override string TypeName
    {
      get
      {
        return "Translation Service Application";
      }
    }

  }
}
